@@ -1,5 +1,9 @@
 #!/usr/bin/env python
 
+"""
+Utility to build Assembly/C/C++ projects
+"""
+
 from .app import app_run
 
 if __name__ == '__main__':
