@@ -2,6 +2,24 @@
 
 import subprocess
 import os
+import re
+
+
+def acquireCliProgramVersion(s):
+	"""
+	Acquire the version of a cli program
+
+	param s: The output of the programm version string.
+
+	example: 'gcc --version'
+	"""
+	regex = r"(\d+)(\.\d+)(\.\d+)?"
+	matches = re.finditer(regex, s, re.MULTILINE)
+	version = None
+	for matchNum, match in enumerate(matches, start=1):
+		version = match.group()
+
+	return version
 
 
 def toString(obj):
@@ -25,12 +43,32 @@ def toString(obj):
 def run_command(cmd):
 	"""
 	Run a shell command
+	The stdout is shown.
+
+	Returns the error code
 	"""
 
 	rv = subprocess.call(cmd, shell=True)
 	return rv
 
 
+def run_command2(cmd):
+	"""
+	Run a shell command
+
+	Returns the stdout
+	"""
+
+	cmdList = cmd.split(" ")
+	rv = None
+	try:
+		rv = subprocess.run(cmdList, stdout=subprocess.PIPE).stdout.decode('utf-8')
+	except FileNotFoundError:
+		pass
+
+	return rv
+
+
 def listPortNames():
 	"""
 	Returns the available port names in the project.
@@ -66,11 +104,11 @@ def egrep(keywords, whole_words=False):
 	param: keywords       Keywords to search for
 	param: whole_words    Search for whole words
 	"""
-	egrep_flags = "-i -nr -R --color"
+	grep_flags = "-i -nr -R --color --no-messages"
 
 	if whole_words:
-		egrep_flags += " -w"
+		grep_flags += " -w"
 
-	cmd = f"egrep {egrep_flags} '{keywords}' src/ inc/ port/ || true"
+	cmd = f"grep -E {grep_flags} '{keywords}' src/ inc/ port/ || true"
 	rv = run_command(cmd)
 	return rv
