@@ -32,7 +32,9 @@ class TestCommand(Command):
 		"""
 		Runs the command
 		"""
-		print(f"File: '{args.file}'")
+
+		if args.file is not None:
+			print(f"File: '{args.file.name}'")
 
 		lst = array2Dict([
 			# Section Key Default Options
